==> kube-integration-1.0.11.tgz: package/lib/kube-native/entity.base.js <==
'use strict';

const _    = require('lodash');
const YAML = require('js-yaml');

const runtimeFields = [
    'metadata.namespace',
    'metadata.selfLink',
    'metadata.uid',
    'metadata.resourceVersion',
    'metadata.creationTimestamp',
];

/**
 * The class should hold a data the represents a k8 asset (service, deployment, ns)
 */
class Entity {

    constructor(data, opt) {
        this._data = data;
        this._opt  = opt;
    }

    getLabels(){
        return _.get(this._getData(), 'metadata.labels');
    }

    getLabelByKey(key) {
        return _.get(this._getData(), 'metadata.labels', {})[key];
    }

    getSelector() {
        return _.get(this, '_opt.selector');
    }

    _getOptions() {
        return _.get(this, '_opt');
    }

    _getData() {
        return _.get(this, '_data', {});
    }

    _getYaml() {
        return YAML.dump(this.toFullJson());
    }

    getFullData() {
        return _.merge(this.toFullJson(), this._getOptions(), { yaml: this._getYaml() });
    }

    addToOptions(data){
        _.merge(this._getOptions(), data);
    }


    toJson() {
        return _.omit(this._getData(),runtimeFields);
    }

    toFullJson(){
        return this._getData();
    }

    getStatus() {
        return _.get(this._getData(), 'status');
    }

    /**
     * Not like getStatus method, this will return analyzed status
     * @return {*}
     */
    getEntityStatus(){
        return _.get(this._getOptions(), 'status');
    }

    getName() {
        return _.get(this._getData(), 'metadata.name');
    }

    getNamespace() {
        return _.get(this._getData(), 'metadata.namespace', 'default');
    }

}

module.exports = Entity;

==> kube-integration-1.0.13.tgz: package/lib/kube-native/entity.base.js <==
'use strict';

const _    = require('lodash');
const YAML = require('js-yaml');

const runtimeFields = [
    'metadata.namespace',
    'metadata.selfLink',
    'metadata.uid',
    'metadata.resourceVersion',
    'metadata.creationTimestamp',
];

/**
 * The class should hold a data the represents a k8 asset (service, deployment, ns)
 */
class Entity {

    constructor(data, opt) {
        this._data = data;
        this._opt  = opt;
    }

    addLabels(data){
        _.set(this._getData(), 'metadata.labels', Object.assign(this.getLabels(), data));
    }

    getLabels(){
        return _.get(this._getData(), 'metadata.labels', {});
    }

    getLabelByKey(key) {
        return _.get(this._getData(), 'metadata.labels', {})[key];
    }

    getSelector() {
        return _.get(this, '_opt.selector');
    }

    _getOptions() {
        return _.get(this, '_opt');
    }

    _getData() {
        return _.get(this, '_data', {});
    }

    _getYaml() {
        return YAML.dump(this.toFullJson());
    }

    getFullData() {
        return _.merge(this.toFullJson(), this._getOptions(), { yaml: this._getYaml() });
    }

    addToOptions(data){
        _.merge(this._getOptions(), data);
    }


    toJson() {
        return _.omit(this._getData(),runtimeFields);
    }

    toFullJson(){
        return this._getData();
    }

    getStatus() {
        return _.get(this._getData(), 'status');
    }

    /**
     * Not like getStatus method, this will return analyzed status
     * @return {*}
     */
    getEntityStatus(){
        return _.get(this._getOptions(), 'status');
    }

    getName() {
        return _.get(this._getData(), 'metadata.name');
    }

    getNamespace() {
        return _.get(this._getData(), 'metadata.namespace', 'default');
    }

}

module.exports = Entity;
